@@ -31,10 +31,33 @@ def _callable(obj):
     else:
         return obj
 
+class _Missing(object):
+    """Represents a value that is missing from the set of passed in request
+    arguments.
+    """
 
-def get_value(d, name, multiple, method='get'):
-    func = getattr(d, method)
-    val = func(name)
+    def __bool__(self):
+        return False
+
+    __nonzero__ = __bool__  # py2 compatibility
+
+    def __repr__(self):
+        return '<webargs.core.missing>'
+
+
+#: Singleton object that represents a value that cannot be found on a request.
+Missing = _Missing()
+
+
+def get_value(d, name, multiple):
+    """Get a value from a dictionary. Handles ``MultiDict`` types when
+    ``multiple=True``. If the value is not found, return `missing`.
+
+    :param dict d: Dictionary to pull the value from.
+    :param str name: Name of the key.
+    :param bool multiple: Whether to handle multiple values.
+    """
+    val = d.get(name, Missing)
     if multiple:
         if hasattr(d, 'getlist'):
             return d.getlist(name)
@@ -59,15 +82,15 @@ class Arg(object):
     :param callable validate: Callable (function or object with ``__call__`` method
         defined) used for custom validation. Returns whether or not the
         value is valid.
-    :param callable use: Preprocessing function used for converting or
-        pre-processing the value. Defaults to noop.
-        Example: ``use=lambda s: s.lower()``
+    :param callable use: Function used for converting or pre-processing the value.
+        Defaults to noop. Example: ``use=lambda s: s.lower()``
     :param bool multiple: Return a list of values for the argument. Useful for
         querystrings or forms that pass multiple values to the same parameter,
         e.g. ``/?name=foo&name=bar``
     :param str error: Custom error message to use if validation fails.
-    :param bool allow_missing: If the argument's value is ``None``, don't
-        include it in the returned arguments dictionary.
+    :param bool allow_missing: If the argument is not found on the request,
+        don't include it in the parsed arguments dictionary.
+    :param str target: Where to pull the value off the request, e.g. ``'json'``.
 
     .. versionchanged:: 0.5.0
         The ``use`` callable is called before type conversion.
@@ -113,6 +136,9 @@ class Arg(object):
         :returns: The validated, converted value
         :raises: ValidationError if validation fails
         """
+        # Prevent "missing" placeholder from getting converted
+        if value is Missing:
+            return value
         if self.multiple and isinstance(value, list):
             return [self._validate(each) for each in value]
         else:
@@ -182,7 +208,11 @@ class Parser(object):
         :param req: The request object to parse.
         :param tuple targets: The targets ('json', 'querystring', etc.) where
             to search for the value.
-        :return: The argument value.
+        :return: The argument value or `Missing` if the value cannot be found
+            on the request.
+
+        :raises: ValidationError if a validation function returns `False` or
+            if a required argument is missing.
         """
         value = None
         if argobj.target:
@@ -195,18 +225,16 @@ class Parser(object):
             if argobj.multiple and not (isinstance(value, list) and len(value)):
                 continue
             # Found the value; validate and return it
-            if value is not None:
+            if value is not Missing:
                 return argobj.validated(value)
-        if value is None:
+        if value is Missing:
             if argobj.default is not None:
                 value = argobj.default
-            else:
-                value = self.fallback(req, name, argobj)
-            if not value and argobj.required:
+            if argobj.required:
                 raise ValidationError('Required parameter {0!r} not found.'.format(name))
         return value
 
-    def parse(self, argmap, req, targets=None):
+    def parse(self, argmap, req, targets=None, validate=None):
         """Main request parsing method.
 
         :param dict argmap: Dictionary of argname:Arg object pairs.
@@ -214,6 +242,9 @@ class Parser(object):
         :param tuple targets: Where on the request to search for values.
             Can include one or more of ``('json', 'querystring', 'form',
             'headers', 'cookies', 'files')``.
+        :param callable validate: Validation function that receives the dictionary
+            of parsed arguments. If the function returns ``False``, the parser
+            will raise a :exc:`ValidationError`.
         :return: A dictionary of parsed arguments
         """
         try:
@@ -222,12 +253,21 @@ class Parser(object):
                 parsed_value = self.parse_arg(argname, argobj, req,
                     targets=targets or self.targets)
                 # Skip missing values
-                can_skip = parsed_value is None or (argobj.multiple
+                can_skip = parsed_value is Missing or (argobj.multiple
                                                     and not len(parsed_value))
                 if argobj.allow_missing and can_skip:
                     continue
                 else:
+                    if parsed_value is Missing:
+                        parsed_value = self.fallback(req, argname, argobj)
                     parsed[argname] = parsed_value
+            if _callable(validate):
+                if not validate(parsed):
+                    raise ValidationError('')
+                    msg = 'Validator {0}({1}) is not True'.format(
+                        validate.__name__, parsed
+                    )
+                    raise ValidationError(self.error or msg)
             return parsed
         except Exception as error:
             if self.error_callback:
@@ -235,25 +275,30 @@ class Parser(object):
             else:
                 self.handle_error(error)
 
-    def use_args(self, argmap, req=None, targets=None, as_kwargs=False):
+    def use_args(self, argmap, req=None, targets=None, as_kwargs=False, validate=None):
         """Decorator that injects parsed arguments into a view function or method.
 
         Example usage with Flask: ::
 
             @app.route('/echo', methods=['get', 'post'])
-            @parser.use_args({'name': Arg(type_=str)})
+            @parser.use_args({'name': Arg(str)})
             def greet(args):
                 return 'Hello ' + args['name']
 
         :param dict argmap: Dictionary of argument_name:Arg object pairs.
         :param tuple targets: Where on the request to search for values.
         :param bool as_kwargs: Whether to insert arguments as keyword arguments.
+        :param callable validate: Validation function that receives the dictionary
+            of parsed arguments. If the function returns ``False``, the parser
+            will raise a :exc:`ValidationError`.
         """
         targets = targets or self.DEFAULT_TARGETS
+
         def decorator(func):
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
-                parsed_args = self.parse(argmap, req=req, targets=targets)
+                parsed_args = self.parse(argmap, req=req, targets=targets,
+                                         validate=validate)
                 if as_kwargs:
                     kwargs.update(parsed_args)
                     return func(*args, **kwargs)
@@ -269,14 +314,16 @@ class Parser(object):
     def use_kwargs(self, *args, **kwargs):
         """Decorator that injects parsed arguments into a view function or method as keyword arguments.
 
-        This is a shortcut to :py:func:`use_args` with as_kwargs=True
+        This is a shortcut to :meth:`use_args` with ``as_kwargs=True``.
 
         Example usage with Flask: ::
 
             @app.route('/echo', methods=['get', 'post'])
-            @parser.use_kwargs({'name': Arg(type_=str)})
+            @parser.use_kwargs({'name': Arg(str)})
             def greet(name):
                 return 'Hello ' + name
+
+        Receives the same ``args`` and ``kwargs`` as :meth:`use_args`.
         """
         kwargs['as_kwargs'] = True
         return self.use_args(*args, **kwargs)
@@ -327,40 +374,40 @@ class Parser(object):
     # Abstract Methods
 
     def parse_json(self, req, name, arg):
-        """Pulls a JSON value from a request object or returns ``None`` if the
+        """Pull a JSON value from a request object or return `Missing` if the
         value cannot be found.
         """
-        return None
+        return Missing
 
     def parse_querystring(self, req, name, arg):
-        """Pulls a value from the query string of a request object or returns ``None`` if
+        """Pull a value from the query string of a request object or return `Missing` if
         the value cannot be found.
         """
-        return None
+        return Missing
 
     def parse_form(self, req, name, arg):
-        """Pulls a value from the form data of a request object or returns
-        ``None`` if the value cannot be found.
+        """Pull a value from the form data of a request object or return
+        `Missing` if the value cannot be found.
         """
-        return None
+        return Missing
 
     def parse_headers(self, req, name, arg):
-        """Pulls a value from the headers or returns ``None`` if the value
+        """Pull a value from the headers or return `Missing` if the value
         cannot be found.
         """
-        return None
+        return Missing
 
     def parse_cookies(self, req, name, arg):
-        """Pulls a cookie value from the request or returns ``None`` if the value
+        """Pull a cookie value from the request or return `Missing` if the value
         cannot be found.
         """
-        return None
+        return Missing
 
     def parse_files(self, req, name, arg):
-        """Pull a file from the request or return ``None`` if the value file
+        """Pull a file from the request or return `Missing` if the value file
         cannot be found.
         """
-        return None
+        return Missing
 
     def handle_error(self, error):
         """Called if an error occurs while parsing args.
@@ -369,6 +416,6 @@ class Parser(object):
 
     def fallback(self, req, name, arg):
         """Called if all other parsing functions (parse_json, parse_form...) return
-        ``None``.
+        `Missing`.
         """
         return None
